# coding: utf-8
from datetime import date

from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
from jmb.i18n.models import TranslationModel, I18NModel
from jmb.core.db.fields import HTMLField, HTMLFieldTinyMCE
from jmb.organization.models import Organization

class Project(DateModel, UserModel, StatusModel, OrderedModel):
    organization = models.ForeignKey (
        Organization,
        null = True, blank = True,
        related_name = "projects",
        db_index = True,
        verbose_name = _("Organization")
    )
    name = models.CharField (
        max_length = 200,
        db_index = True,
        verbose_name = _("Name"),
    )
    description = models.TextField (
        null = True, blank = True,
        verbose_name = _("Description"),
    )
    date_start = models.DateField (
        db_index = True,
        default = date.today,
        verbose_name = _("Start Date"),
    )
    date_end = models.DateField (
        null = True, blank = True,
        db_index = True,
        verbose_name =  _("End Date"),
    )
    accepted = models.BooleanField (
        ## PROGETTO accettato - da offerta/opportunita' diventa commessa/progetto
        default = False,
        db_index = True,
        verbose_name = _("Accepted"),
    )

    class Meta:
        verbose_name = _('Project')
        verbose_name_plural = _('Projects')

    def __unicode__(self):
        return self.name

# if settings.CMS_ENABLED:
#     import namespace.appname.model.cms.plugins
#     import namespace.appname.model.cms.app
